import { coerceBooleanProperty } from '@angular/cdk/coercion';
import * as i0 from '@angular/core';
import { Injectable, InjectionToken, EventEmitter, Component, ViewEncapsulation, ChangeDetectionStrategy, SkipSelf, Inject, Input, Output, HostBinding, NgModule } from '@angular/core';
import { randomId } from '@yukawa/chain-base-angular-client';
import { yukawaAnimations } from '@yukawa/chain-base-angular-comp/animations';
import { ReplaySubject, Subject, filter, takeUntil } from 'rxjs';
import { HttpErrorResponse } from '@angular/common/http';
import { uniqueId } from 'lodash-es';
import * as i1 from '@jsverse/transloco';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i3 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i4 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import * as i5 from '@yukawa/chain-base-angular-comp/shared';
import { SharedModule } from '@yukawa/chain-base-angular-comp/shared';

class YukawaAlertService {
    _translocoService;
    _onDismiss = new ReplaySubject(1);
    _onShow = new ReplaySubject(1);
    /**
     * Constructor
     */
    constructor(_translocoService) {
        this._translocoService = _translocoService;
    }
    // -----------------------------------------------------------------------------------------------------
    // @ Accessors
    // -----------------------------------------------------------------------------------------------------
    /**
     * Getter for onDismiss
     */
    get onDismiss() {
        return this._onDismiss.asObservable();
    }
    /**
     * Getter for onShow
     */
    get onShow() {
        return this._onShow.asObservable();
    }
    // -----------------------------------------------------------------------------------------------------
    // @ Public methods
    // -----------------------------------------------------------------------------------------------------
    /**
     * Generates an alert configuration from the provided error object.
     * Uses translation keys `ERROR.NO_INTERNET_CONNECTION` and `ERROR.UNKNOWN`.
     *
     * @param error
     * @param  environment
     */
    generateErrorAlert(error, environment) {
        let message = this._translocoService.translate(!window.navigator.onLine
            ? 'ERROR.NO_INTERNET_CONNECTION'
            : 'ERROR.UNKNOWN');
        if (!environment.production) {
            message += '\n\n';
            if (typeof error === 'string') {
                message += error;
            }
            else {
                message += `${error.message}`;
                if (error instanceof HttpErrorResponse && error.error) {
                    message += `\n\n${error.error.text}`;
                }
            }
        }
        return {
            name: uniqueId('app_alert_'),
            type: 'error',
            message,
        };
    }
    /**
     * Dismiss the alert
     *
     * @param name
     */
    dismiss(name) {
        // Return if the name is not provided
        if (!name) {
            return;
        }
        // Execute the observable
        this._onDismiss.next(name);
    }
    /**
     * Show the dismissed alert
     *
     * @param name
     * @param config
     */
    show(name, config) {
        // Return if the name is not provided
        if (!name) {
            return;
        }
        // Execute the observable
        this._onShow.next(!config ? name : { ...config, name });
    }
    /** @nocollapse */ static ɵfac = function YukawaAlertService_Factory(t) { return new (t || YukawaAlertService)(i0.ɵɵinject(i1.TranslocoService)); };
    /** @nocollapse */ static ɵprov = /** @pureOrBreakMyCode */ i0.ɵɵdefineInjectable({ token: YukawaAlertService, factory: YukawaAlertService.ɵfac, providedIn: 'root' });
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(YukawaAlertService, [{
        type: Injectable,
        args: [{
                providedIn: 'root',
            }]
    }], () => [{ type: i1.TranslocoService }], null); })();

const _c0 = [[["", "yukawaAlertTitle", ""]], "*", [["", "yukawaAlertIcon", ""]]];
const _c1 = ["[yukawaAlertTitle]", "*", "[yukawaAlertIcon]"];
function YukawaAlertComponent_div_0_div_1_Template(rf, ctx) { if (rf & 1) {
    i0.ɵɵelement(0, "div", 10);
} }
function YukawaAlertComponent_div_0_div_2_mat_icon_4_Template(rf, ctx) { if (rf & 1) {
    i0.ɵɵelement(0, "mat-icon", 9);
} if (rf & 2) {
    const ctx_r1 = i0.ɵɵnextContext(3);
    i0.ɵɵproperty("svgIcon", ctx_r1.iconConfig.primary);
} }
function YukawaAlertComponent_div_0_div_2_mat_icon_5_Template(rf, ctx) { if (rf & 1) {
    i0.ɵɵelement(0, "mat-icon", 9);
} if (rf & 2) {
    const ctx_r1 = i0.ɵɵnextContext(3);
    i0.ɵɵproperty("svgIcon", ctx_r1.iconConfig.accent);
} }
function YukawaAlertComponent_div_0_div_2_mat_icon_6_Template(rf, ctx) { if (rf & 1) {
    i0.ɵɵelement(0, "mat-icon", 9);
} if (rf & 2) {
    const ctx_r1 = i0.ɵɵnextContext(3);
    i0.ɵɵproperty("svgIcon", ctx_r1.iconConfig.warn);
} }
function YukawaAlertComponent_div_0_div_2_mat_icon_7_Template(rf, ctx) { if (rf & 1) {
    i0.ɵɵelement(0, "mat-icon", 9);
} if (rf & 2) {
    const ctx_r1 = i0.ɵɵnextContext(3);
    i0.ɵɵproperty("svgIcon", ctx_r1.iconConfig.basic);
} }
function YukawaAlertComponent_div_0_div_2_mat_icon_8_Template(rf, ctx) { if (rf & 1) {
    i0.ɵɵelement(0, "mat-icon", 9);
} if (rf & 2) {
    const ctx_r1 = i0.ɵɵnextContext(3);
    i0.ɵɵproperty("svgIcon", ctx_r1.iconConfig.info);
} }
function YukawaAlertComponent_div_0_div_2_mat_icon_9_Template(rf, ctx) { if (rf & 1) {
    i0.ɵɵelement(0, "mat-icon", 9);
} if (rf & 2) {
    const ctx_r1 = i0.ɵɵnextContext(3);
    i0.ɵɵproperty("svgIcon", ctx_r1.iconConfig.success);
} }
function YukawaAlertComponent_div_0_div_2_mat_icon_10_Template(rf, ctx) { if (rf & 1) {
    i0.ɵɵelement(0, "mat-icon", 9);
} if (rf & 2) {
    const ctx_r1 = i0.ɵɵnextContext(3);
    i0.ɵɵproperty("svgIcon", ctx_r1.iconConfig.warning);
} }
function YukawaAlertComponent_div_0_div_2_mat_icon_11_Template(rf, ctx) { if (rf & 1) {
    i0.ɵɵelement(0, "mat-icon", 9);
} if (rf & 2) {
    const ctx_r1 = i0.ɵɵnextContext(3);
    i0.ɵɵproperty("svgIcon", ctx_r1.iconConfig.error);
} }
function YukawaAlertComponent_div_0_div_2_Template(rf, ctx) { if (rf & 1) {
    i0.ɵɵelementStart(0, "div", 11)(1, "div", 12);
    i0.ɵɵprojection(2, 2);
    i0.ɵɵelementEnd();
    i0.ɵɵelementStart(3, "div", 13);
    i0.ɵɵtemplate(4, YukawaAlertComponent_div_0_div_2_mat_icon_4_Template, 1, 1, "mat-icon", 14)(5, YukawaAlertComponent_div_0_div_2_mat_icon_5_Template, 1, 1, "mat-icon", 14)(6, YukawaAlertComponent_div_0_div_2_mat_icon_6_Template, 1, 1, "mat-icon", 14)(7, YukawaAlertComponent_div_0_div_2_mat_icon_7_Template, 1, 1, "mat-icon", 14)(8, YukawaAlertComponent_div_0_div_2_mat_icon_8_Template, 1, 1, "mat-icon", 14)(9, YukawaAlertComponent_div_0_div_2_mat_icon_9_Template, 1, 1, "mat-icon", 14)(10, YukawaAlertComponent_div_0_div_2_mat_icon_10_Template, 1, 1, "mat-icon", 14)(11, YukawaAlertComponent_div_0_div_2_mat_icon_11_Template, 1, 1, "mat-icon", 14);
    i0.ɵɵelementEnd()();
} if (rf & 2) {
    const ctx_r1 = i0.ɵɵnextContext(2);
    i0.ɵɵadvance(4);
    i0.ɵɵproperty("ngIf", ctx_r1.type === "primary");
    i0.ɵɵadvance();
    i0.ɵɵproperty("ngIf", ctx_r1.type === "accent");
    i0.ɵɵadvance();
    i0.ɵɵproperty("ngIf", ctx_r1.type === "warn");
    i0.ɵɵadvance();
    i0.ɵɵproperty("ngIf", ctx_r1.type === "basic");
    i0.ɵɵadvance();
    i0.ɵɵproperty("ngIf", ctx_r1.type === "info");
    i0.ɵɵadvance();
    i0.ɵɵproperty("ngIf", ctx_r1.type === "success");
    i0.ɵɵadvance();
    i0.ɵɵproperty("ngIf", ctx_r1.type === "warning");
    i0.ɵɵadvance();
    i0.ɵɵproperty("ngIf", ctx_r1.type === "error");
} }
function YukawaAlertComponent_div_0_ng_container_7_Template(rf, ctx) { if (rf & 1) {
    i0.ɵɵelementContainerStart(0);
    i0.ɵɵelement(1, "div", 15);
    i0.ɵɵpipe(2, "marked");
    i0.ɵɵelementContainerEnd();
} if (rf & 2) {
    const ctx_r1 = i0.ɵɵnextContext(2);
    i0.ɵɵadvance();
    i0.ɵɵproperty("innerHTML", i0.ɵɵpipeBind1(2, 1, ctx_r1.message), i0.ɵɵsanitizeHtml);
} }
function YukawaAlertComponent_div_0_Template(rf, ctx) { if (rf & 1) {
    const _r1 = i0.ɵɵgetCurrentView();
    i0.ɵɵelementStart(0, "div", 1);
    i0.ɵɵtemplate(1, YukawaAlertComponent_div_0_div_1_Template, 1, 0, "div", 2)(2, YukawaAlertComponent_div_0_div_2_Template, 12, 8, "div", 3);
    i0.ɵɵelementStart(3, "div", 4)(4, "div", 5);
    i0.ɵɵprojection(5);
    i0.ɵɵelementEnd();
    i0.ɵɵelementStart(6, "div", 6);
    i0.ɵɵtemplate(7, YukawaAlertComponent_div_0_ng_container_7_Template, 3, 3, "ng-container", 7);
    i0.ɵɵprojection(8, 1);
    i0.ɵɵelementEnd()();
    i0.ɵɵelementStart(9, "button", 8);
    i0.ɵɵlistener("click", function YukawaAlertComponent_div_0_Template_button_click_9_listener() { i0.ɵɵrestoreView(_r1); const ctx_r1 = i0.ɵɵnextContext(); return i0.ɵɵresetView(ctx_r1.dismiss(true)); });
    i0.ɵɵelement(10, "mat-icon", 9);
    i0.ɵɵelementEnd()();
} if (rf & 2) {
    const ctx_r1 = i0.ɵɵnextContext();
    i0.ɵɵproperty("@fadeIn", !ctx_r1.dismissed)("@fadeOut", !ctx_r1.dismissed);
    i0.ɵɵadvance();
    i0.ɵɵproperty("ngIf", ctx_r1.appearance === "border");
    i0.ɵɵadvance();
    i0.ɵɵproperty("ngIf", ctx_r1.showIcon);
    i0.ɵɵadvance(5);
    i0.ɵɵproperty("ngIf", ctx_r1.message);
    i0.ɵɵadvance(3);
    i0.ɵɵproperty("svgIcon", ctx_r1.iconConfig.dismiss);
} }
const YUKAWA_ALERT_ICON_CONFIG = new InjectionToken('YUKAWA_ALERT_ICON_CONFIG');
class YukawaAlertComponent {
    _changeDetectorRef;
    _parentChangeDetectorRef;
    _yukawaAlertService;
    iconConfig;
    /* eslint-disable @typescript-eslint/naming-convention */
    static ngAcceptInputType_dismissible;
    static ngAcceptInputType_dismissed;
    static ngAcceptInputType_showIcon;
    /* eslint-enable @typescript-eslint/naming-convention */
    appearance = 'soft';
    dismissed = false;
    dismissible = false;
    name;
    showIcon = true;
    type = 'primary';
    message;
    dismissedChanged = new EventEmitter();
    _unsubscribeAll = new Subject();
    /**
     * Constructor
     */
    constructor(_changeDetectorRef, _parentChangeDetectorRef, _yukawaAlertService, iconConfig) {
        this._changeDetectorRef = _changeDetectorRef;
        this._parentChangeDetectorRef = _parentChangeDetectorRef;
        this._yukawaAlertService = _yukawaAlertService;
        this.iconConfig = iconConfig;
        this.name = randomId();
    }
    // -----------------------------------------------------------------------------------------------------
    // @ Accessors
    // -----------------------------------------------------------------------------------------------------
    /**
     * Host binding for component classes
     */
    get classList() {
        return {
            /* eslint-disable @typescript-eslint/naming-convention */
            'yukawa-alert-appearance-border': this.appearance === 'border',
            'yukawa-alert-appearance-fill': this.appearance === 'fill',
            'yukawa-alert-appearance-outline': this.appearance === 'outline',
            'yukawa-alert-appearance-soft': this.appearance === 'soft',
            'yukawa-alert-dismissed': this.dismissed,
            'yukawa-alert-dismissible': this.dismissible,
            'yukawa-alert-show-icon': this.showIcon,
            'yukawa-alert-type-primary': this.type === 'primary',
            'yukawa-alert-type-accent': this.type === 'accent',
            'yukawa-alert-type-warn': this.type === 'warn',
            'yukawa-alert-type-basic': this.type === 'basic',
            'yukawa-alert-type-info': this.type === 'info',
            'yukawa-alert-type-success': this.type === 'success',
            'yukawa-alert-type-warning': this.type === 'warning',
            'yukawa-alert-type-error': this.type === 'error',
            /* eslint-enable @typescript-eslint/naming-convention */
        };
    }
    // -----------------------------------------------------------------------------------------------------
    // @ Lifecycle hooks
    // -----------------------------------------------------------------------------------------------------
    /**
     * On changes
     *
     * @param changes
     */
    ngOnChanges(changes) {
        // Dismissed
        if ('dismissed' in changes) {
            // Coerce the value to a boolean
            this.dismissed = coerceBooleanProperty(changes.dismissed.currentValue);
            // Dismiss/show the alert
            this._toggleDismiss(this.dismissed);
        }
        // Dismissible
        if ('dismissible' in changes) {
            // Coerce the value to a boolean
            this.dismissible = coerceBooleanProperty(changes.dismissible.currentValue);
        }
        // Show icon
        if ('showIcon' in changes) {
            // Coerce the value to a boolean
            this.showIcon = coerceBooleanProperty(changes.showIcon.currentValue);
        }
    }
    /**
     * On init
     */
    ngOnInit() {
        // Subscribe to the dismiss calls
        this._yukawaAlertService.onDismiss
            .pipe(filter(name => this.name === name), takeUntil(this._unsubscribeAll))
            .subscribe(() => {
            // Dismiss the alert
            this.dismiss();
        });
        // Subscribe to the show calls
        this._yukawaAlertService.onShow
            .pipe(filter(name => typeof name === 'object' ? this.name === name.name : this.name === name), takeUntil(this._unsubscribeAll))
            .subscribe((name) => {
            if (typeof name === 'object') {
                Object.assign(this, name);
            }
            // Show the alert
            this.show();
        });
    }
    /**
     * On destroy
     */
    ngOnDestroy() {
        // Unsubscribe from all subscriptions
        this._unsubscribeAll.next(null);
        this._unsubscribeAll.complete();
    }
    // -----------------------------------------------------------------------------------------------------
    // @ Public methods
    // -----------------------------------------------------------------------------------------------------
    /**
     * Dismiss the alert
     */
    dismiss(self) {
        if (self) {
            this._yukawaAlertService.dismiss(this.name);
            return;
        }
        // Return if the alert is already dismissed
        if (this.dismissed) {
            return;
        }
        // Dismiss the alert
        this._toggleDismiss(true);
    }
    /**
     * Show the dismissed alert
     */
    show() {
        // Return if the alert is already showing
        if (!this.dismissed) {
            return;
        }
        // Show the alert
        this._toggleDismiss(false);
    }
    // -----------------------------------------------------------------------------------------------------
    // @ Private methods
    // -----------------------------------------------------------------------------------------------------
    /**
     * Dismiss/show the alert
     *
     * @param dismissed
     * @private
     */
    _toggleDismiss(dismissed) {
        // Return if the alert is not dismissible
        if (!this.dismissible) {
            return;
        }
        // Set the dismissed
        this.dismissed = dismissed;
        // Execute the observable
        this.dismissedChanged.next(this.dismissed);
        // Notify the change detector
        this._changeDetectorRef.detectChanges();
        this._parentChangeDetectorRef.detectChanges();
    }
    /** @nocollapse */ static ɵfac = function YukawaAlertComponent_Factory(t) { return new (t || YukawaAlertComponent)(i0.ɵɵdirectiveInject(i0.ChangeDetectorRef), i0.ɵɵdirectiveInject(i0.ChangeDetectorRef, 4), i0.ɵɵdirectiveInject(YukawaAlertService), i0.ɵɵdirectiveInject(YUKAWA_ALERT_ICON_CONFIG)); };
    /** @nocollapse */ static ɵcmp = /** @pureOrBreakMyCode */ i0.ɵɵdefineComponent({ type: YukawaAlertComponent, selectors: [["yukawa-alert"]], hostVars: 2, hostBindings: function YukawaAlertComponent_HostBindings(rf, ctx) { if (rf & 2) {
            i0.ɵɵclassMap(ctx.classList);
        } }, inputs: { appearance: "appearance", dismissed: "dismissed", dismissible: "dismissible", name: "name", showIcon: "showIcon", type: "type", message: "message" }, outputs: { dismissedChanged: "dismissedChanged" }, exportAs: ["yukawaAlert"], features: [i0.ɵɵNgOnChangesFeature], ngContentSelectors: _c1, decls: 1, vars: 1, consts: [["class", "yukawa-alert-container overflow-hidden", 4, "ngIf"], [1, "yukawa-alert-container", "overflow-hidden"], ["class", "yukawa-alert-border", 4, "ngIf"], ["class", "yukawa-alert-icon", 4, "ngIf"], [1, "yukawa-alert-content", "overflow-auto"], [1, "yukawa-alert-title"], [1, "yukawa-alert-message"], [4, "ngIf"], ["mat-icon-button", "", 1, "yukawa-alert-dismiss-button", 3, "click"], [3, "svgIcon"], [1, "yukawa-alert-border"], [1, "yukawa-alert-icon"], [1, "yukawa-alert-custom-icon"], [1, "yukawa-alert-default-icon"], [3, "svgIcon", 4, "ngIf"], [3, "innerHTML"]], template: function YukawaAlertComponent_Template(rf, ctx) { if (rf & 1) {
            i0.ɵɵprojectionDef(_c0);
            i0.ɵɵtemplate(0, YukawaAlertComponent_div_0_Template, 11, 6, "div", 0);
        } if (rf & 2) {
            i0.ɵɵproperty("ngIf", !ctx.dismissible || ctx.dismissible && !ctx.dismissed);
        } }, dependencies: [i2.NgIf, i3.MatIconButton, i4.MatIcon, i5.MarkedPipe], encapsulation: 2, data: { animation: yukawaAnimations }, changeDetection: 0 });
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(YukawaAlertComponent, [{
        type: Component,
        args: [{ selector: 'yukawa-alert', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, animations: yukawaAnimations, exportAs: 'yukawaAlert', template: "<div\n    class=\"yukawa-alert-container overflow-hidden\"\n    *ngIf=\"!dismissible || dismissible && !dismissed\"\n    [@fadeIn]=\"!dismissed\"\n    [@fadeOut]=\"!dismissed\">\n\n    <!-- Border -->\n    <div\n        class=\"yukawa-alert-border\"\n        *ngIf=\"appearance === 'border'\"></div>\n\n    <!-- Icon -->\n    <div\n        class=\"yukawa-alert-icon\"\n        *ngIf=\"showIcon\">\n\n        <!-- Custom icon -->\n        <div class=\"yukawa-alert-custom-icon\">\n            <ng-content select=\"[yukawaAlertIcon]\"></ng-content>\n        </div>\n\n        <!-- Default icons -->\n        <div class=\"yukawa-alert-default-icon\">\n\n            <mat-icon\n                *ngIf=\"type === 'primary'\"\n                [svgIcon]=\"iconConfig.primary\"></mat-icon>\n\n            <mat-icon\n                *ngIf=\"type === 'accent'\"\n                [svgIcon]=\"iconConfig.accent\"></mat-icon>\n\n            <mat-icon\n                *ngIf=\"type === 'warn'\"\n                [svgIcon]=\"iconConfig.warn\"></mat-icon>\n\n            <mat-icon\n                *ngIf=\"type === 'basic'\"\n                [svgIcon]=\"iconConfig.basic\"></mat-icon>\n\n            <mat-icon\n                *ngIf=\"type === 'info'\"\n                [svgIcon]=\"iconConfig.info\"></mat-icon>\n\n            <mat-icon\n                *ngIf=\"type === 'success'\"\n                [svgIcon]=\"iconConfig.success\"></mat-icon>\n\n            <mat-icon\n                *ngIf=\"type === 'warning'\"\n                [svgIcon]=\"iconConfig.warning\"></mat-icon>\n\n            <mat-icon\n                *ngIf=\"type === 'error'\"\n                [svgIcon]=\"iconConfig.error\"></mat-icon>\n\n        </div>\n\n    </div>\n\n    <!-- Content -->\n    <div class=\"yukawa-alert-content overflow-auto\">\n\n        <div class=\"yukawa-alert-title\">\n            <ng-content select=\"[yukawaAlertTitle]\"></ng-content>\n        </div>\n\n        <div class=\"yukawa-alert-message\">\n            <ng-container *ngIf=\"message\">\n                <div [innerHTML]=\"message | marked\"></div>\n            </ng-container>\n            <ng-content></ng-content>\n        </div>\n\n    </div>\n\n    <!-- Dismiss button -->\n    <button\n        class=\"yukawa-alert-dismiss-button\"\n        mat-icon-button\n        (click)=\"dismiss(true)\">\n        <mat-icon [svgIcon]=\"iconConfig.dismiss\"></mat-icon>\n    </button>\n\n</div>\n" }]
    }], () => [{ type: i0.ChangeDetectorRef }, { type: i0.ChangeDetectorRef, decorators: [{
                type: SkipSelf
            }] }, { type: YukawaAlertService }, { type: undefined, decorators: [{
                type: Inject,
                args: [YUKAWA_ALERT_ICON_CONFIG]
            }] }], { appearance: [{
            type: Input
        }], dismissed: [{
            type: Input
        }], dismissible: [{
            type: Input
        }], name: [{
            type: Input
        }], showIcon: [{
            type: Input
        }], type: [{
            type: Input
        }], message: [{
            type: Input
        }], dismissedChanged: [{
            type: Output
        }], classList: [{
            type: HostBinding,
            args: ['class']
        }] }); })();
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassDebugInfo(YukawaAlertComponent, { className: "YukawaAlertComponent", filePath: "alert.component.ts", lineNumber: 50 }); })();

class YukawaAlertModule {
    static forRoot(iconConfig = {
        primary: 'check_circle',
        accent: 'check_circle',
        warn: 'warning',
        basic: 'check_circle',
        info: 'info',
        success: 'check_circle',
        warning: 'warning',
        error: 'error',
        dismiss: 'close',
    }) {
        return {
            ngModule: YukawaAlertModule,
            providers: [
                {
                    provide: YUKAWA_ALERT_ICON_CONFIG,
                    useValue: iconConfig,
                },
            ],
        };
    }
    /** @nocollapse */ static ɵfac = function YukawaAlertModule_Factory(t) { return new (t || YukawaAlertModule)(); };
    /** @nocollapse */ static ɵmod = /** @pureOrBreakMyCode */ i0.ɵɵdefineNgModule({ type: YukawaAlertModule });
    /** @nocollapse */ static ɵinj = /** @pureOrBreakMyCode */ i0.ɵɵdefineInjector({ imports: [CommonModule,
            MatButtonModule,
            MatIconModule,
            SharedModule] });
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(YukawaAlertModule, [{
        type: NgModule,
        args: [{
                declarations: [
                    YukawaAlertComponent,
                ],
                imports: [
                    CommonModule,
                    MatButtonModule,
                    MatIconModule,
                    SharedModule,
                ],
                exports: [
                    YukawaAlertComponent,
                ],
            }]
    }], null, null); })();
(function () { (typeof ngJitMode === "undefined" || ngJitMode) && i0.ɵɵsetNgModuleScope(YukawaAlertModule, { declarations: [YukawaAlertComponent], imports: [CommonModule,
        MatButtonModule,
        MatIconModule,
        SharedModule], exports: [YukawaAlertComponent] }); })();

/**
 * Generated bundle index. Do not edit.
 */

export { YUKAWA_ALERT_ICON_CONFIG, YukawaAlertComponent, YukawaAlertModule, YukawaAlertService };
//# sourceMappingURL=yukawa-chain-base-angular-comp-alert.mjs.map
