import { EventEmitter, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { FormBuilder, FormControl, FormGroup, FormGroupDirective, NgForm } from '@angular/forms';
import { ErrorStateMatcher } from '@angular/material/core';
import { MatSnackBar, MatSnackBarConfig } from '@angular/material/snack-bar';
import { ActivatedRoute } from '@angular/router';
import { TranslocoService } from '@jsverse/transloco';
import { YukawaConfirmationService } from '@yukawa/chain-base-angular-comp/confirmation';
import { IMediaWatcherService } from '@yukawa/chain-base-angular-comp/shared';
import { Observable, Subject } from 'rxjs';
import { DeepPartial, Nullable } from 'simplytyped';
import { QueryTableDatasource, QueryTableEntry } from '../model';
import { IQueryTableEntryDetail } from '../types';
import { QueryTableEntryFormComponent } from './form/form.component';
import * as i0 from "@angular/core";
export type FormOperations = 'delete' | 'save' | 'upload';
export declare class MyErrorStateMatcher implements ErrorStateMatcher {
    isErrorState(control: FormControl | null, form: FormGroupDirective | NgForm | null): boolean;
}
/**
 * Base component class for form views using the {@link QueryTableEntryFormComponent}.
 */
export declare abstract class QueryTableFormComponent<TEntity extends object = any, TViewConfig extends DeepPartial<TEntity> = TEntity, TEntry extends QueryTableEntry<TEntity, TViewConfig> = QueryTableEntry<TEntity, TViewConfig>, TDatasource extends QueryTableDatasource<TEntity, TViewConfig, TEntry> = QueryTableDatasource<TEntity, TViewConfig, TEntry>, TOperation extends FormOperations = FormOperations> implements OnInit, OnChanges, OnDestroy {
    #private;
    protected readonly _activationRoute: ActivatedRoute;
    protected readonly _confirmationService: YukawaConfirmationService;
    protected readonly _formBuilder: FormBuilder;
    protected readonly _matSnackBar: MatSnackBar;
    protected readonly _mediaWatcherService: IMediaWatcherService;
    readonly _translateKey: string;
    protected readonly _translocoService: TranslocoService;
    pageType: 'new' | 'edit';
    readonly matcher: MyErrorStateMatcher;
    protected _isScreenSmall: boolean;
    protected _isValid: boolean;
    private _currentEntityOperation;
    private _entryDetails;
    private _entryForm;
    private _uploaded;
    private readonly snackBarConfig;
    abstract datasource: TDatasource;
    abstract detailsComponent: QueryTableEntryFormComponent;
    abstract entry: TEntry;
    protected constructor(_activationRoute: ActivatedRoute, _confirmationService: YukawaConfirmationService, _formBuilder: FormBuilder, _matSnackBar: MatSnackBar, _mediaWatcherService: IMediaWatcherService, _translateKey: string, _translocoService: TranslocoService);
    /**
     * Use this form to maintain custom form inputs which will be included into the validation {@link isValid}.
     * To create the form with the given controls use {@link createEntryForm}.
     */
    get entryForm(): FormGroup;
    /**
     * The entry details to display in the form.
     */
    get entryDetails(): Array<IQueryTableEntryDetail>;
    get currentEntityOperation(): Nullable<TOperation>;
    set currentEntityOperation(value: Nullable<TOperation>);
    get isDeleting(): boolean;
    get isSaving(): boolean;
    get isUploading(): boolean;
    get isEnabled(): boolean;
    set isEnabled(value: boolean);
    get isValid(): boolean;
    get uploaded(): void | null;
    get unsubscribeAll(): Subject<void>;
    protected abstract get inputChanged(): EventEmitter<boolean>;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * Create {@link entryForm} with the given controls.
     *
     * @param controls
     */
    createEntryForm<T extends object>(controls: T): void;
    detailsInputChanged($event: boolean): void;
    /**
     * Save the entity with optional entity properties.
     *
     * @param entity Optional entity properties to save.
     */
    save(entity?: DeepPartial<TEntity>): Promise<Nullable<TEntry>>;
    delete(): Promise<boolean>;
    protected uploadFile(entity: TEntity, file: File, uploadFile: (entity: TEntity, file: File, onProgress?: (progress: number) => void) => Observable<void | null>, messageCallback: (progress?: number) => string, snackBarConfig?: Pick<MatSnackBarConfig, 'panelClass' | 'horizontalPosition' | 'verticalPosition'>): Promise<void | null>;
    /**
     * Save the entity with optional constructor parameters.
     *
     * @param entryArgs Optional constructor parameters.
     * @protected
     */
    protected saveEntity(...entryArgs: Array<unknown>): {
        changes: Partial<TEntity>;
        result: TEntry;
    };
    /**
     * Create a new entity from the given entity. If the entry id is not empty, the entity is enriched with the entry entity values.
     *
     * @param entity The entity to create a new entity from.
     * @protected
     */
    protected newEntity(entity: TEntity): TEntity;
    /**
     * Implement in derived class and call {@link saveEntity} to save the entity with optional constructor parameters.
     *
     * @param entity Optional entity properties to save.
     * @protected
     */
    protected abstract saveEntry(entity?: DeepPartial<TEntity>): Promise<TEntry>;
    /**
     * Implement in derived class and specify optional constructor parameters and enrich the entity with optional values.
     * Return just the entity if no constructor parameters are present, otherwise return the final entry using {@link datasource.newEntry}.
     * When returning the final entry, the entity must be enriched with the {@link entry.entity} values to preserve the original entity id.
     *
     * @param  entity The entity to create a new entity from.
     * @param entryArgs Optional constructor parameters.
     * @protected
     */
    protected abstract createEntry(entity: TEntity, ...entryArgs: Array<unknown>): TEntity | TEntry;
    static ɵfac: i0.ɵɵFactoryDeclaration<QueryTableFormComponent<any, any, any, any, any>, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<QueryTableFormComponent<any, any, any, any, any>>;
}
