import { EventEmitter } from '@angular/core';
import '@awesome-nodes/object/data';
import { ConfigService, Exception, TemplateString, TemplateStringValues } from '@yukawa/chain-base-angular-client';
import { EntityFilter, QueryResult, TableFilter } from '@yukawa/chain-base-angular-domain';
import { BehaviorSubject } from 'rxjs';
import { ConstructorFor, DeepPartial, Nullable } from 'simplytyped';
import { IQueryTableEntry } from '../types';
export declare abstract class QueryTableDatasource<TEntity extends object = any, TViewConfig extends DeepPartial<TEntity> = TEntity, TEntry extends IQueryTableEntry<TEntity, TViewConfig> = IQueryTableEntry<TEntity, TViewConfig>, TFilter extends TableFilter = EntityFilter> {
    #private;
    protected readonly _entry: ConstructorFor<TEntry>;
    private readonly _defaultFilter;
    protected readonly _configService: ConfigService;
    readonly entries: TEntry[];
    readonly entriesLoaded: EventEmitter<TEntry[]>;
    readonly entrySelected: EventEmitter<TEntry>;
    readonly entryUpdated: EventEmitter<TEntry>;
    readonly entryDeleted: EventEmitter<TEntry>;
    protected query: QueryResult<TEntity>;
    private _queryResult;
    protected constructor(_entry: ConstructorFor<TEntry>, _defaultFilter?: TFilter, _configService?: ConfigService);
    get defaultFilter(): EntityFilter;
    get loading(): boolean;
    get loading$(): BehaviorSubject<Nullable<boolean>>;
    get queryResult(): Nullable<QueryResult<TEntry>>;
    newEntry(item?: TEntity, ...entityArgs: Array<unknown>): TEntry;
    init(filter?: TFilter): Promise<QueryResult<TEntry>>;
    selectEntry(id?: string): void;
    abstract create(entry: TEntry): Promise<TEntry>;
    abstract read(filter?: TFilter): Promise<Array<TEntity>>;
    abstract update(entry: TEntry, entity?: Partial<TEntity>): Promise<TEntry>;
    abstract delete(entry: TEntry): Promise<void>;
    abstract getByID(id: number | string): Promise<TEntry>;
}
export declare class QueryTableDatasourceException extends Exception {
    constructor(message: TemplateString, messageTemplateValues?: TemplateStringValues, innerException?: Error | undefined);
}
