import { EventEmitter } from '@angular/core';
import { MatPaginator } from '@angular/material/paginator';
import { MatSort, Sort as MaterialSort } from '@angular/material/sort';
import { EntityFilter, QueryResult, TableFilter } from '@yukawa/chain-base-angular-domain';
import { QueryTableSource } from '@yukawa/chain-base-angular-store';
import { Observable } from 'rxjs';
import { ConstructorFor, DeepPartial, Nullable, Required, StringKeys } from 'simplytyped';
import { IQueryTableEntry, IQueryTableEntryDetail } from '../types';
import { QueryTableDatasource } from './query-table-datasource.model';
interface IQueryTableEntryDetailGroup extends Required<Partial<IQueryTableEntryDetail>, 'group' | 'key' | 'label'> {
    details: Array<IQueryTableEntryDetail>;
}
export type EntryGroupDirection = 'vertical' | 'horizontal';
export interface IQueryTableGroupDetail {
    name: string;
    direction: EntryGroupDirection;
    details: Array<IQueryTableEntryDetail>;
}
export interface Sort<T extends object = any> extends MaterialSort {
    active: StringKeys<T>;
}
export declare abstract class QueryTableStore<TEntity extends object, TViewConfig extends DeepPartial<TEntity> = TEntity, TEntry extends IQueryTableEntry<TEntity, TViewConfig> = IQueryTableEntry<TEntity, TViewConfig>, TFilter extends TableFilter | EntityFilter = EntityFilter, TDataSource extends QueryTableDatasource<TEntity, TViewConfig, TEntry, TFilter> = any> extends QueryTableSource<TFilter, TEntry> {
    #private;
    readonly paginator: MatPaginator;
    readonly sort: MatSort;
    private readonly tableEntry;
    readonly datasource: TDataSource;
    readonly headers: (IQueryTableEntryDetail<any, any, import("../types").ISelectOption<any, any>> | IQueryTableEntryDetailGroup)[];
    readonly displayedColumns: string[];
    readonly detailGroups: Map<string, IQueryTableGroupDetail[]>;
    readonly detailValues: Map<string, Map<string, unknown>>;
    readonly loaded: EventEmitter<TEntry[]>;
    readonly entrySelected: EventEmitter<TEntry>;
    readonly actionColumns: {
        index?: number;
        name: string;
    }[];
    private _selectedEntry;
    protected constructor(paginator: MatPaginator, sort: MatSort, tableFilter: TFilter, tableEntry: ConstructorFor<TEntry>, datasource: TDataSource);
    get entries(): Array<TEntry>;
    get selectedEntry(): Nullable<TEntry>;
    set selectedEntry(value: Nullable<TEntry>);
    load(): void;
    reload(): void;
    /**
     * Retrieves and caches table entry detail values.
     *
     * @param row
     * @param detail
     * @param transform
     * @return
     */
    getRowDetail<T = unknown>(row: TEntry, detail: IQueryTableEntryDetail, transform?: (value: T) => T): T;
    dispose(): void;
    protected onLoaded(rows: TEntry[]): void;
    protected queryTable(): Observable<QueryResult<TEntry>>;
    protected applyFilter(filter: TFilter): void;
    protected entryUpdated(entry: TEntry): void;
    protected init(entries?: Array<TEntry>): void;
    protected queryEntries(entityFilter?: TFilter): Observable<QueryResult<TEntry>>;
    private createDetailGroups;
}
export {};
