import { Overlay } from '@angular/cdk/overlay';
import { AfterViewInit, ChangeDetectorRef, ComponentRef, ElementRef, EventEmitter, OnChanges, OnDestroy, OnInit, QueryList, SimpleChanges, TemplateRef, ViewContainerRef } from '@angular/core';
import { MatPaginator } from '@angular/material/paginator';
import { MatSort } from '@angular/material/sort';
import { ActivatedRoute, ParamMap, Router } from '@angular/router';
import { ConfigService } from '@yukawa/chain-base-angular-client';
import { EmojiService, IMediaWatcherService } from '@yukawa/chain-base-angular-comp/shared';
import { TableFilter } from '@yukawa/chain-base-angular-domain';
import { ConstructorFor, DeepPartial, Nullable, PlainObject } from 'simplytyped';
import { QueryTableEntry, QueryTableStore, Sort } from './model';
import { IQueryTableEntry, IQueryTableEntryComponent, IQueryTableEntryDetail, IQueryTableEntryDetailComponent } from './types';
import * as i0 from "@angular/core";
export interface Action<T extends string = string> {
    type: 'icon' | 'link' | 'button';
    icon?: string;
    name: T;
    available?: (row: IQueryTableEntry<any>) => boolean;
    class?: string;
    disabled?: boolean;
    customTooltip?: string;
}
export interface EntryAction<T extends IQueryTableEntry = IQueryTableEntry> {
    action: string;
    row: T;
}
export declare class QueryTableComponent<TEntity extends object = any, TViewConfig extends DeepPartial<TEntity> = TEntity, TEntry extends QueryTableEntry<TEntity, TViewConfig> = QueryTableEntry<TEntity, TViewConfig>> implements OnInit, OnChanges, AfterViewInit, OnDestroy {
    #private;
    private readonly _activatedRoute;
    private readonly _changeDetectorRef;
    private readonly _configService;
    private readonly _elementRef;
    private readonly _emojiService;
    private readonly _overlay;
    private readonly _router;
    private readonly _viewContainerRef;
    private readonly _mediaWatcherService;
    table: ElementRef;
    noDataTemplate: TemplateRef<any>;
    paginator: MatPaginator;
    sort: MatSort;
    containers: QueryList<ViewContainerRef>;
    filter: TableFilter;
    dataStore: ConstructorFor<QueryTableStore<TEntity, TViewConfig, TEntry>>;
    defaultSort: Sort<TEntry>;
    pageSize: number;
    reloadEntry: EventEmitter<TEntry>;
    selectedEntryComponent: Nullable<ConstructorFor<IQueryTableEntryComponent<TEntity, TViewConfig>>>;
    cellComponents: Nullable<Map<string, ConstructorFor<IQueryTableEntryDetailComponent>>>;
    displayPager: boolean;
    displayActions: boolean;
    actions: Action<string>[];
    rowSelect: boolean;
    expandOnEntrySelect: boolean;
    expandOnEntrySelectCollapsedTitle: string;
    expandOnEntrySelectExpandedTitle: string;
    entryAction: EventEmitter<EntryAction<TEntry>>;
    entryActionsLabel: string;
    noEntriesLabel: string | undefined;
    queryParams: PlainObject;
    applyFilter: Nullable<(params: ParamMap) => void | Promise<void>>;
    dataSource: QueryTableStore<TEntity, TViewConfig, TEntry>;
    readonly entrySelected: EventEmitter<TEntry>;
    expandedRow: Nullable<number>;
    overflowHidden: boolean;
    constructor(_activatedRoute: ActivatedRoute, _changeDetectorRef: ChangeDetectorRef, _configService: ConfigService, _elementRef: ElementRef, _emojiService: EmojiService, _overlay: Overlay, _router: Router, _viewContainerRef: ViewContainerRef, _mediaWatcherService: IMediaWatcherService);
    get defaultPageSize(): number;
    set defaultPageSize(value: number);
    get expandedComponent(): ComponentRef<IQueryTableEntryComponent<TEntity, TViewConfig>>;
    get skipParams(): boolean;
    ngOnInit(): Promise<void>;
    ngOnChanges(changes: SimpleChanges): Promise<void>;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    getRowDetail(row: TEntry, detail: IQueryTableEntryDetail): any;
    onSortChanged($event: Sort): Promise<void>;
    navigate(params?: {
        pageSize?: number;
        firstResult?: number;
        orderBy?: string;
        orderDir?: string;
    } & PlainObject, skipParams?: boolean): Promise<boolean>;
    reload(): void;
    expandButtonClick($event: MouseEvent, row: TEntry): Promise<void>;
    rowIsExpanded(row: TEntry): boolean;
    expandRow(index: Nullable<number>): Promise<void>;
    getCellComponent(key: string): ConstructorFor<IQueryTableEntryDetailComponent>;
    rowClicked(row: Nullable<TEntry>): void;
    onEntryAction($event: MouseEvent, row: TEntry, action: Action): void;
    private applyFilterQuery;
    private updateTableHeight;
    private showNoDataOverlay;
    private dismissNoDataOverlay;
    private getOverlayPositions;
    private onEntrySelected;
    static ɵfac: i0.ɵɵFactoryDeclaration<QueryTableComponent<any, any, any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<QueryTableComponent<any, any, any>, "yukawa-query-table", never, { "filter": { "alias": "filter"; "required": false; }; "dataStore": { "alias": "dataStore"; "required": false; }; "defaultSort": { "alias": "defaultSort"; "required": false; }; "pageSize": { "alias": "pageSize"; "required": false; }; "reloadEntry": { "alias": "reloadEntry"; "required": false; }; "selectedEntryComponent": { "alias": "selectedEntryComponent"; "required": false; }; "cellComponents": { "alias": "cellComponents"; "required": false; }; "displayPager": { "alias": "displayPager"; "required": false; }; "displayActions": { "alias": "displayActions"; "required": false; }; "actions": { "alias": "actions"; "required": false; }; "rowSelect": { "alias": "rowSelect"; "required": false; }; "expandOnEntrySelect": { "alias": "expandOnEntrySelect"; "required": false; }; "expandOnEntrySelectCollapsedTitle": { "alias": "expandOnEntrySelectCollapsedTitle"; "required": false; }; "expandOnEntrySelectExpandedTitle": { "alias": "expandOnEntrySelectExpandedTitle"; "required": false; }; "entryActionsLabel": { "alias": "entryActionsLabel"; "required": false; }; "noEntriesLabel": { "alias": "noEntriesLabel"; "required": false; }; "queryParams": { "alias": "queryParams"; "required": false; }; "applyFilter": { "alias": "applyFilter"; "required": false; }; }, { "entryAction": "entryAction"; "dataSource": "dataSource"; "entrySelected": "entrySelected"; }, never, never, false, never>;
}
