import { ValidatorFn } from '@angular/forms';
import { HashMap } from '@jsverse/transloco/lib/types';
import { AutoComplete, AutocompleteSearchFunction } from '@yukawa/chain-base-angular-comp/shared';
import { Observable } from 'rxjs';
import { DeepPartial, StringKeys } from 'simplytyped';
import { ISelectOption, ISelectOptions } from './select-option.types';
export type EntryDetailType = 'autocomplete' | 'boolean' | 'component' | 'date' | 'dateTime' | 'image' | 'multiline' | 'multiselect' | 'number' | 'select' | 'tag' | 'text' | 'time' | 'url' | 'version';
export type ValidationMessages = Record<string, {
    message: string;
    params?: HashMap;
}>;
export interface IQueryTableEntryDetail<TValue = any, TObject extends object = any, TOption extends ISelectOption = ISelectOption<TValue, TObject>> {
    autocomplete?: AutoComplete;
    autocompleteOptions$?: Observable<Array<TOption>> | Promise<Array<TOption>>;
    autocompleteSearch?: AutocompleteSearchFunction;
    canEdit: boolean;
    class?: string;
    compareWith?: (o1: any, o2: any) => boolean;
    emojiSupport: boolean;
    /**
     * Used to map server error responses to entry details.
     */
    entityName?: string;
    formIndex?: number;
    group?: string;
    groupByField?: boolean | string;
    groupDirection?: 'vertical' | 'horizontal';
    groupIndex?: number;
    key: string;
    label: string;
    markdownSupport: boolean;
    maxLength?: number;
    maxValue?: TValue;
    minLength?: number;
    minValue?: TValue;
    options$?: Observable<Array<TOption>> | Promise<Array<TOption>>;
    options?: Array<TOption>;
    placeholder?: string;
    readonly?: boolean;
    required: boolean;
    rows?: number;
    selectOptions?: ISelectOptions<TValue, TObject>;
    showInDetails?: boolean;
    showInTable?: boolean;
    sortable?: boolean;
    tableGroup?: boolean;
    cellClass?: string;
    type: EntryDetailType;
    validators?: Array<ValidatorFn>;
    validationMessages?: ValidationMessages;
    value: TValue;
}
export interface IQueryTableEntry<TEntity extends object = any, TViewConfig extends DeepPartial<TEntity> = TEntity> {
    id: string;
    entity: TEntity;
    name: string;
    selected: boolean;
    details: Map<StringKeys<TViewConfig>, IQueryTableEntryDetail>;
    viewConfig: TViewConfig;
    init(): void;
}
export interface IQueryTableEntryComponent<TEntity extends object = any, TViewConfig extends DeepPartial<TEntity> = TEntity> {
    entry: IQueryTableEntry<TEntity, TViewConfig>;
}
export interface IQueryTableEntryDetailComponent<TEntity extends object = any> extends IQueryTableEntryComponent<TEntity> {
    detail: IQueryTableEntryDetail<TEntity>;
}
