import { Exception, TemplateString, TemplateStringValues } from '@yukawa/chain-base-angular-client';
import { Nullable } from 'simplytyped';
export declare const semVerRexExp: RegExp;
export declare const bitMaskRegExp: RegExp;
interface IVersion {
    major: number;
    minor: number;
    patch: number;
    prerelease?: string;
    buildmetadata?: string;
}
export declare class Version implements IVersion {
    major: number;
    minor: number;
    patch: number;
    prerelease?: string;
    buildmetadata?: string;
    constructor(data?: Partial<IVersion> | string | number);
    /**
     * Parses the provided version string and returns a Version object.
     *
     * @param text
     * @throws {VersionException}
     */
    static parse(text: string): Version;
    static tryParse(text: string): Nullable<Version>;
    toLong(): number;
    toString(): string;
    /**
     * @param version should be a string in the format of 'vX.Y.Z' where X, Y, Z are
     * For example, 'v1.2.3' represents version 1.2.3.
     * @param maxBits is the number of bits used to represent the number each version number: [vMAJOR.MINOR.PATCH].
     * 8 bits are enough to represent the number [v0.0.0] to [v255.255.255].
     * @returns An unique integer representing the version.
     */
    protected maskVersion(version: string, maxBits?: number): number;
    /**
     * @param version should be the integer returned by [maskVersion].
     * @param maxBits is the number of bits used to represent the number each version number: [vMAJOR.MINOR.PATCH].
     * 8 bits are enough to represent the number [v0.0.0] to [v255.255.255].
     * @return the original string representing the version.
     */
    protected unmaskVersion(version: number, maxBits?: number): string;
}
export declare class VersionException extends Exception {
    constructor(message: TemplateString, messageTemplateValues?: TemplateStringValues, innerException?: Error);
}
export {};
