import { PipeTransform } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Sanitizes a value by removing potentially harmful content.
 *
 * This pipe is used to sanitize user input or untrusted data to prevent
 * cross-site scripting (XSS) attacks and other security vulnerabilities.
 *
 * The pipe performs the following sanitization steps:
 * - Decodes URL-encoded characters
 * - Removes HTML tags, script tags, SVG tags, and MathML tags
 * - Removes query parameters
 * - Removes JavaScript event handlers and inline scripts
 * - Removes CSS expressions and inline styles
 * - Removes comments
 * - Removes JavaScript protocol handlers
 * - Removes data URIs and unwanted protocols
 * - Removes base64-encoded data
 *
 * @param value The value to be sanitized.
 * @returns The sanitized value as a string.
 *
 * @example
 *
 * <div>{{ unsafeValue | sanitizer }}</div>
 *
 */
export declare class SanitizerPipe implements PipeTransform {
    transform(value: any): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<SanitizerPipe, never>;
    static ɵpipe: i0.ɵɵPipeDeclaration<SanitizerPipe, "sanitizer", false>;
}
